@@ -1,6 +1,6 @@
-__version__ = "0.1.0"
+__version__ = "0.1.2"
 
-from .io import yaml_load, yaml_dump, save, load, rm, json_load, json_dump
+from .io import yaml_load, yaml_dump, save, load, json_load, json_dump
 from .path import *
 from .progress_bar import probar
 from .performance import MeasureTime
