@@ -1,42 +1,12 @@
-import os
-import sys
-import shutil
-from glob import glob
 from sparrow.path import rel_to_abs
 import pickle
 from typing import Union, List, Dict
-from .core import broadcast
+import shutil
 
 
-@broadcast
-def rm(PATH):
-    """Enhanced rm, support for regular expressions"""
-
-    def _rm(path):
-        """remove path"""
-        if os.path.exists(path):
-            if os.path.isfile(path):
-                os.remove(path)
-            elif os.path.isdir(path):
-                shutil.rmtree(path)
-            else:
-                print(f"{path} is illegal.")
-
-    path_list = glob(PATH)
-    for path in path_list:
-        _rm(path)
-
-
-def path(string: str) -> str:
-    """Adaptive to different platforms"""
-    platform = sys.platform.lower()
-    if platform in ("linux", "darwin"):
-        return string.replace("\\", "/")
-    elif platform in ("win", "win32"):
-        return string.replace("/", "\\")
-    else:
-        return string
-
+def rm(*files: str):
+    for file in files:
+        shutil.rmtree(file, ignore_errors=True)
 
 def save(filename, file):
     with open(filename, "wb") as fw:
@@ -49,23 +19,24 @@ def load(filename):
     return file
 
 
-def json_load(filepath: str, rel=False):
+def json_load(filepath: str, rel=False, mode='rb'):
     import orjson
     abs_path = rel_to_abs(filepath, parents=1) if rel else filepath
-    with open(abs_path, 'rb') as f:
+    with open(abs_path, mode=mode) as f:
         return orjson.loads(f.read())
 
 
-def json_dump(data: Union[List, Dict], filepath: str, rel=False, indent_2=False):
+def json_dump(data: Union[List, Dict], filepath: str, rel=False, indent_2=False, mode='wb'):
     import orjson
     orjson_option = 0
     if indent_2:
         orjson_option = orjson.OPT_INDENT_2
     abs_path = rel_to_abs(filepath, parents=1) if rel else filepath
-    with open(abs_path, 'wb') as f:
+    with open(abs_path, mode=mode) as f:
         f.write(orjson.dumps(data, option=orjson_option))
 
-def yaml_dump(filepath, data, rel_path=False):
+
+def yaml_dump(filepath, data, rel_path=False, mode='w'):
     abs_path = rel_to_abs(filepath, parents=1) if rel_path else filepath
     from yaml import dump
 
@@ -73,11 +44,11 @@ def yaml_dump(filepath, data, rel_path=False):
         from yaml import CDumper as Dumper
     except ImportError:
         from yaml import Dumper
-    with open(abs_path, "w", encoding="utf-8") as fw:
+    with open(abs_path, mode=mode, encoding="utf-8") as fw:
         fw.write(dump(data, Dumper=Dumper, allow_unicode=True, indent=4))
 
 
-def yaml_load(filepath, rel_path=False):
+def yaml_load(filepath, rel_path=False, mode='r'):
     abs_path = rel_to_abs(filepath, parents=1) if rel_path else filepath
     from yaml import load
 
@@ -85,7 +56,7 @@ def yaml_load(filepath, rel_path=False):
         from yaml import CLoader as Loader
     except ImportError:
         from yaml import Loader
-    with open(abs_path, "r", encoding="utf-8") as stream:
+    with open(abs_path, mode=mode, encoding="utf-8") as stream:
         #     stream = stream.read()
         content = load(stream, Loader=Loader)
     return content
